@@ -17,7 +17,26 @@ def grass_raster_setnull(
     else:
         grass.run_command("r.null", map=raster_nm, setnull=null_values)
 
+def grass_raster_setnull_array(input,output,values,grass):
+    
+    raster_array = garray.array(mapname=input)
+    if (len(values) > 0):
+        mask = np.isin(raster_array, values)
+        raster_array[mask] = -9999
 
+    temparray = garray.array()
+    temparray[:, :] = raster_array[:, :]
+    temparray.write(mapname=output, overwrite=True)
+    grass.run_command("r.null", map=output, setnull=[-9999, 0])
+    exp = "%s = int(%s)" % (
+        output,
+        output,
+    )
+    grass.run_command("r.mapcalc", expression=exp, overwrite=True)
+    del temparray
+    del raster_array
+
+    
 #####
 
 
@@ -107,6 +126,7 @@ def grass_raster_r_stream_extract(
     stream_vector,
     direction,
     memory,
+    stream_length = -1,
 ):
     """using provided elevation, accumulation and threshold to derived
         stream_raster,and direction
@@ -117,17 +137,32 @@ def grass_raster_r_stream_extract(
     -------
 
     """
-    grass.run_command(
-        "r.stream.extract",
-        elevation=elevation,
-        accumulation=accumulation,
-        threshold=threshold,
-        stream_raster=stream_raster,
-        direction=direction,
-        stream_vector=stream_vector,
-        overwrite=True,
-        memory=memory,
-    )
+    if stream_length < 0:
+        grass.run_command(
+            "r.stream.extract",
+            elevation=elevation,
+            accumulation=accumulation,
+            threshold=threshold,
+            stream_raster=stream_raster,
+            direction=direction,
+            stream_vector=stream_vector,
+            overwrite=True,
+            memory=memory,
+        )
+    else:
+        grass.run_command(
+            "r.stream.extract",
+            elevation=elevation,
+            accumulation=accumulation,
+            threshold=threshold,
+            stream_raster=stream_raster,
+            direction=direction,
+            stream_vector=stream_vector,
+            overwrite=True,
+            stream_length = stream_length,
+            memory=memory,
+        )
+                
 
 
 ###
@@ -184,7 +219,7 @@ def grass_raster_r_external(grass, input, output):
     -------
 
     """
-    grass.run_command("r.external", input=input, output=output, overwrite=True)
+    grass.run_command("r.in.gdal", input=input, output=output, overwrite=True)
 
 
 ###
