@@ -187,6 +187,8 @@ def save_modified_attributes_to_outputs(mapoldnew_info,tempfolder,OutputFolder,c
         mapoldnew_info = mapoldnew_info.drop(columns=drop_cat_colnms)
         mapoldnew_info.to_file(os.path.join(OutputFolder,cat_name))
 
+        outline = create_watershed_boundary(mapoldnew_info)
+        outline.to_file(os.path.join(OutputFolder,"outline.shp"))
         create_geo_jason_file(os.path.join(OutputFolder,cat_name))
 
     else:
@@ -215,8 +217,15 @@ def save_modified_attributes_to_outputs(mapoldnew_info,tempfolder,OutputFolder,c
         drop_cat_colnms = cat_colnms[cat_colnms.isin(["SHAPE","SubId_1", "Id","nsubid2", "nsubid","ndownsubid","Old_DowSub","Join_Count","TARGET_FID","Id","SubID_Oldr","HRU_ID_N_1","HRU_ID_N_2","facters","Old_DowSubId"])]
         mapoldnew_info = mapoldnew_info.drop(columns=drop_cat_colnms)
         mapoldnew_info.to_file(os.path.join(OutputFolder,cat_name))
+        outline = create_watershed_boundary(mapoldnew_info)
+        outline.to_file(os.path.join(OutputFolder,"outline.shp"))
         return mapoldnew_info
 
+def create_watershed_boundary(mapoldnew_info):
+    wb = mapoldnew_info.copy(deep=True)[['geometry']]
+    wb["ID"] = 1
+    wb = wb.dissolve(by="ID", aggfunc='first',as_index=False)
+    return wb
 
 def Remove_Unselected_Lake_Attribute_In_Finalcatinfo_purepy(finalcat_ply, Conn_Lake_Ids):
     """Functions will set lake id not in Conn_Lake_Ids to -1.2345 in attribute
@@ -319,7 +328,7 @@ def create_geo_jason_file(Input_Polygon_path):
     Names_in = os.path.basename(Input_Polygon_path).split('_')
     n_charc = len(Names_in)
     version  = Names_in[n_charc - 1][0:4]
-    TOLERANCEs = [0.0001,0.0005,0.001,0.005,0.01,0.05]
+    TOLERANCEs = [0.0001,0.005]
 
 
     head_name_cat = "finalcat_info"
