@@ -2,8 +2,8 @@ import numpy as np
 import sys
 import os
 import csv
-import tempfile 
-import copy 
+import tempfile
+import copy
 import pandas as pd
 from arcgis.features import GeoAccessor, GeoSeriesAccessor
 import arcpy
@@ -78,7 +78,7 @@ def combine_catchments_covered_by_the_same_lake_arcgis(
     Path_final_cat_ply="#"
     Path_final_cat_riv="#"
 
-    ##define input files from routing prodcut 
+    ##define input files from routing prodcut
     for file in os.listdir(Routing_Product_Folder):
         if file.endswith(".shp"):
             if 'catchment_without_merging_lakes' in file:
@@ -89,14 +89,14 @@ def combine_catchments_covered_by_the_same_lake_arcgis(
                 Path_Con_Lake_ply = os.path.join(Routing_Product_Folder, file)
             if 'sl_non_connected_lake' in file:
                 Path_NonCon_Lake_ply = os.path.join(Routing_Product_Folder, file)
-            if 'obs_gauges' in file:
+            if 'obs_gauges' in file or 'poi' in file:
                 Path_obs_gauge_point = os.path.join(Routing_Product_Folder, file)
             if 'finalcat_info' in file:
                 Path_final_cat_ply = os.path.join(Routing_Product_Folder, file)
             if 'finalcat_info_riv' in file:
-                Path_final_cat_riv = os.path.join(Routing_Product_Folder, file)                
+                Path_final_cat_riv = os.path.join(Routing_Product_Folder, file)
 
-    if Path_Catchment_Polygon == '#' or  Path_River_Polyline =='#':
+    if Path_Catchment_Polygon == '#':
         print("Invalid routing product folder ")
 
 
@@ -108,7 +108,7 @@ def combine_catchments_covered_by_the_same_lake_arcgis(
 
     if not os.path.exists(OutputFolder):
         os.makedirs(OutputFolder)
-        
+
     tempfolder = os.path.join(
         tempfile.gettempdir(), "basinmaker_" + str(np.random.randint(1, 10000 + 1))
     )
@@ -118,9 +118,9 @@ def combine_catchments_covered_by_the_same_lake_arcgis(
 
     ### create a copy of shapfiles in temp folder
     Path_Temp_final_rviply = os.path.join(OutputFolder,"temp_finalriv_ply" + str(np.random.randint(1, 10000 + 1)) + ".shp")
-    
+
     Path_Temp_final_rvi = os.path.join(OutputFolder,"temp_finalriv_riv" + str(np.random.randint(1, 10000 + 1)) + ".shp")
-    
+
     ### read riv ply info
     ### read attribute table
     finalrivply_info = pd.DataFrame.spatial.from_featureclass(Path_final_rivply)
@@ -136,29 +136,29 @@ def combine_catchments_covered_by_the_same_lake_arcgis(
 
     mapoldnew_info = remove_possible_small_subbasins(mapoldnew_info = mapoldnew_info, area_thresthold = 10*30*30/1000/1000)
     # update topology for new attribute table
-    
+
     mapoldnew_info.loc[mapoldnew_info['Lake_Cat'] > 0,'RivLength'] = -1.2345
     mapoldnew_info.loc[mapoldnew_info['Lake_Cat'] > 0,'RivSlope'] = -1.2345
     mapoldnew_info.loc[mapoldnew_info['Lake_Cat'] > 0,'FloodP_n'] = -1.2345
     mapoldnew_info.loc[mapoldnew_info['Lake_Cat'] > 0,'Ch_n'] = -1.2345
     mapoldnew_info.loc[mapoldnew_info['Lake_Cat'] > 0,'Max_DEM'] = -1.2345
     mapoldnew_info.loc[mapoldnew_info['Lake_Cat'] > 0,'Min_DEM'] = -1.2345
-    
+
     if 'DA_Chn_L' in mapoldnew_info.columns:
         mapoldnew_info.loc[mapoldnew_info['Lake_Cat'] > 0,'RivLength'] = -1.2345
         mapoldnew_info.loc[mapoldnew_info['Lake_Cat'] > 0,'RivLength'] = -1.2345
-            
-    mapoldnew_info = update_topology(mapoldnew_info, UpdateStreamorder=-1)    
-    
+
+    mapoldnew_info = update_topology(mapoldnew_info, UpdateStreamorder=-1)
+
     mapoldnew_info['DowSubId'] = mapoldnew_info['DowSubId'].astype('int32')
-    
+
     if len(os.path.basename(Path_Catchment_Polygon).split('_')) == 5:
         cat_name = "finalcat_info_"+os.path.basename(Path_Catchment_Polygon).split('_')[4]
         riv_name = "finalcat_info_riv_"+os.path.basename(Path_Catchment_Polygon).split('_')[4]
     else:
         cat_name =  "finalcat_info.shp"
         riv_name =  "finalcat_info_riv.shp"
-              
+
     save_modified_attributes_to_outputs(
         mapoldnew_info=mapoldnew_info,
         tempfolder=tempfolder,
@@ -167,4 +167,4 @@ def combine_catchments_covered_by_the_same_lake_arcgis(
         riv_name =riv_name,
         Path_final_riv = Path_final_riv,
     )
-    return 
+    return
