@@ -149,6 +149,25 @@ def simplify_routing_structure_by_drainage_area_method(
             OutputFolder=OutputFolder,
         )
 
+def add_point_of_interest_sites_in_routing_product_method(
+    routing_product_folder= '#',
+    path_to_points_of_interest_points = '#',
+    clean_exist_pois = True,
+    path_output_folder = "#",
+    gis_platform="qgis",
+):
+    if gis_platform == "purepy":
+        from basinmaker.postprocessing.assigninterestsites import (
+            define_interest_sites,
+        )
+        define_interest_sites(
+            routing_product_folder= routing_product_folder,
+            path_to_points_of_interest_points = path_to_points_of_interest_points,
+            clean_exist_pois = clean_exist_pois,
+            path_output_folder = path_output_folder,
+        )
+    return
+
 def select_part_of_routing_product_method(
     Path_Points,
     Gauge_NMS,
