@@ -8,8 +8,8 @@ import sys
 import os
 import csv
 import pandas as pd
-import tempfile 
-import copy 
+import tempfile
+import copy
 
 import sys, os
 sys.path.append(os.path.join(os.path.dirname(__file__), '..'))
@@ -172,7 +172,7 @@ def Select_Routing_product_based_SubId_arcgis(
     Path_final_cat_ply="#"
     Path_final_cat_riv="#"
 
-    ##define input files from routing prodcut 
+    ##define input files from routing prodcut
     for file in os.listdir(Routing_Product_Folder):
         if file.endswith(".shp"):
             if 'catchment_without_merging_lakes' in file:
@@ -183,12 +183,12 @@ def Select_Routing_product_based_SubId_arcgis(
                 Path_Con_Lake_ply = os.path.join(Routing_Product_Folder, file)
             if 'sl_non_connected_lake' in file:
                 Path_NonCon_Lake_ply = os.path.join(Routing_Product_Folder, file)
-            if 'obs_gauges' in file:
+            if 'obs_gauges' in file or 'poi' in file:
                 Path_obs_gauge_point = os.path.join(Routing_Product_Folder, file)
             if 'finalcat_info' in file:
                 Path_final_cat_ply = os.path.join(Routing_Product_Folder, file)
             if 'finalcat_info_riv' in file:
-                Path_final_cat_riv = os.path.join(Routing_Product_Folder, file)                
+                Path_final_cat_riv = os.path.join(Routing_Product_Folder, file)
 
     if Path_Catchment_Polygon == '#' or  Path_River_Polyline =='#':
         print("Invalid routing product folder ")
@@ -201,7 +201,7 @@ def Select_Routing_product_based_SubId_arcgis(
     down_colnm = "DowSubId"
 
     ##3
-    
+
     cat_ply = pd.DataFrame.spatial.from_featureclass(Path_Catchment_Polygon)
 
     hyshdinfo = cat_ply[[sub_colnm, down_colnm]].astype("int32").values
@@ -209,7 +209,7 @@ def Select_Routing_product_based_SubId_arcgis(
     Gauge_col_Name = "Has_POI"
     if "Has_POI" not in cat_ply.columns:
         Gauge_col_Name = "Has_Gauge"
-        
+
     ### Loop for each downstream id
 
     if not os.path.exists(OutputFolder):
@@ -220,7 +220,7 @@ def Select_Routing_product_based_SubId_arcgis(
         ### Loop for each downstream id
         OutHyID = mostdownid[i_down]
         OutHyID2 = mostupstreamid[i_down]
-            
+
         ## find all subid control by this subid
         HydroBasins1 = defcat(hyshdinfo, OutHyID)
         if OutHyID2 > 0:
@@ -244,23 +244,23 @@ def Select_Routing_product_based_SubId_arcgis(
 
     cat_ply_select = cat_ply.loc[cat_ply['SubId'].isin(HydroBasins_All)]
 
-    cat_ply_select.spatial.to_featureclass(location=Outputfilename_cat,overwrite=True,sanitize_columns=False) 
+    cat_ply_select.spatial.to_featureclass(location=Outputfilename_cat,overwrite=True,sanitize_columns=False)
     Outputfilename_cat_riv = os.path.join(
         OutputFolder, os.path.basename(Path_River_Polyline)
     )
 
     cat_riv = pd.DataFrame.spatial.from_featureclass(Path_River_Polyline)
-    
 
-    cat_riv_select = cat_riv.loc[cat_riv['SubId'].isin(HydroBasins)]
-    
-    cat_riv_select.spatial.to_featureclass(location=Outputfilename_cat_riv,overwrite=True,sanitize_columns=False) 
-    
+
+    cat_riv_select = cat_riv.loc[cat_riv['SubId'].isin(HydroBasins_All)]
+
+    cat_riv_select.spatial.to_featureclass(location=Outputfilename_cat_riv,overwrite=True,sanitize_columns=False)
+
     cat_ply_select = pd.DataFrame.spatial.from_featureclass(Outputfilename_cat)
     Connect_Lake_info = cat_ply_select.loc[cat_ply_select["Lake_Cat"] == 1]
     Connect_Lakeids = np.unique(Connect_Lake_info["HyLakeId"].values)
     Connect_Lakeids = Connect_Lakeids[Connect_Lakeids > 0]
-    
+
     NConnect_Lake_info = cat_ply_select.loc[cat_ply_select["Lake_Cat"] == 2]
     NonCL_Lakeids = np.unique(NConnect_Lake_info["HyLakeId"].values)
     NonCL_Lakeids = NonCL_Lakeids[NonCL_Lakeids > 0]
@@ -269,14 +269,16 @@ def Select_Routing_product_based_SubId_arcgis(
 
         sl_con_lakes = pd.DataFrame.spatial.from_featureclass(Path_Con_Lake_ply)
         sl_con_lakes = sl_con_lakes.loc[sl_con_lakes['Hylak_id'].isin(Connect_Lakeids)]
-        sl_con_lakes.spatial.to_featureclass(location=os.path.join(OutputFolder,os.path.basename(Path_Con_Lake_ply)),overwrite=True,sanitize_columns=False)
+        if len(sl_con_lakes) > 0:
+            sl_con_lakes.spatial.to_featureclass(location=os.path.join(OutputFolder,os.path.basename(Path_Con_Lake_ply)),overwrite=True,sanitize_columns=False)
 
 
     if len(NonCL_Lakeids) > 0 and Path_NonCon_Lake_ply != "#":
         sl_non_con_lakes = pd.DataFrame.spatial.from_featureclass(Path_NonCon_Lake_ply)
         sl_non_con_lakes = sl_non_con_lakes.loc[sl_non_con_lakes['Hylak_id'].isin(NonCL_Lakeids)]
-        sl_non_con_lakes.spatial.to_featureclass(location=os.path.join(OutputFolder,os.path.basename(Path_NonCon_Lake_ply)),overwrite=True,sanitize_columns=False)
-    
+        if len(sl_non_con_lakes) > 0:
+            sl_non_con_lakes.spatial.to_featureclass(location=os.path.join(OutputFolder,os.path.basename(Path_NonCon_Lake_ply)),overwrite=True,sanitize_columns=False)
+
     sl_gauge_info = cat_ply_select.loc[cat_ply_select[Gauge_col_Name] > 0]
     sl_gauge_nm = np.unique(sl_gauge_info["Obs_NM"].values)
     sl_gauge_nm = sl_gauge_nm[sl_gauge_nm != 'nan']
@@ -284,8 +286,8 @@ def Select_Routing_product_based_SubId_arcgis(
         all_gauge = pd.DataFrame.spatial.from_featureclass(Path_obs_gauge_point)
         sl_gauge = all_gauge.loc[all_gauge['Obs_NM'].isin(sl_gauge_nm)]
         sl_gauge.spatial.to_featureclass(location=os.path.join(OutputFolder,os.path.basename(Path_obs_gauge_point)),overwrite=True,sanitize_columns=False)
-    
-    return 
+
+    return
 
 
-################################################################
\ No newline at end of file
+################################################################
