@@ -1,8 +1,15 @@
 import os
-
+import glob,shutil
 from simpledbf import Dbf5
 
 # define internal file names
+def copy_files_with_extension(src_folder,tar_folder,ext):
+
+    files = glob.iglob(os.path.join(src_folder, ext))
+    for file in files:
+        if os.path.isfile(file):
+            t = shutil.copy2(file, tar_folder)
+
 Internal_Constant_Names = {
     "cat_add_lake_old_fdr": "cat_add_lake_old_fdr",
     "cat_add_lake": "cat_add_lake",
@@ -80,6 +87,8 @@ COLUMN_NAMES_CONSTANT = [
     "DA_Chn_Slp",
     "outletLat",
     "outletLng",
+    "k",
+    "c",
 ]
 
 COLUMN_NAMES_CONSTANT_CLEAN = [
@@ -120,7 +129,9 @@ COLUMN_NAMES_CONSTANT_CLEAN = [
     "DA_Chn_Slp",
     "outletLat",
     "outletLng",
-    "Has_Gauge"
+    "Has_Gauge",
+    "k",
+    "c",
 ]
 
 
@@ -190,7 +201,7 @@ COLUMN_NAMES_CONSTANT_HRU = [
     "DA_Chn_L",
     "DA_Slope",
     "DA_Chn_Slp",
-    "Has_Gauge" ,   
+    "Has_Gauge" ,
 ]
 
 
@@ -232,6 +243,8 @@ COLUMN_TYPES_CONSTANT = [
     "Real",
     "Real",
     "Real",
+    "Real",
+    "Real",
 ]
 
 DEFALUT_FLOOD_N = 0.09
@@ -242,7 +255,7 @@ max_riv_slope = 1
 min_bkf_width = 0.1
 min_bkf_depth = 0.1
 min_riv_lenth = 90
-    
+
 def Dbf_To_Dataframe(file_path):
     """Transfer an input dbf file to dataframe
 
